echo "complete _"										>> $EXTENSION/build_order.txt
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v qdbus) == "" ]] && echo "Installing qt" && extension --install qt && echo "Finished qt"
fi
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v sphinx-autogen) == "" ]] && echo "Installing py_sphinx" && extension --install py_sphinx && echo "Finished py_sphinx"
fi

if [ $BUILD_ALL == "false" ] && [ -f /usr/share/ECM/cmake/ECMConfigVersion.cmake ] && [[ $(cat /usr/share/ECM/cmake/ECMConfigVersion.cmake | grep 'set(PACKAGE_VERSION "6.13.0")') == "" ]]; then
	echo "extra_cmake_modules" 							>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "extra_cmake_modules" 							>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
